gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[libeufin] branch master updated: renaming function argument


From: gnunet
Subject: [libeufin] branch master updated: renaming function argument
Date: Sun, 16 Apr 2023 21:30:19 +0200

This is an automated email from the git hooks/post-receive script.

ms pushed a commit to branch master
in repository libeufin.

The following commit(s) were added to refs/heads/master by this push:
     new cdee48b0 renaming function argument
cdee48b0 is described below

commit cdee48b0fceed6256cd22eafbe03c581f49a9211
Author: MS <ms@taler.net>
AuthorDate: Sun Apr 16 21:30:10 2023 +0200

    renaming function argument
---
 .../kotlin/tech/libeufin/sandbox/ConversionService.kt    | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/sandbox/src/main/kotlin/tech/libeufin/sandbox/ConversionService.kt 
b/sandbox/src/main/kotlin/tech/libeufin/sandbox/ConversionService.kt
index 4045d10e..c52d74dd 100644
--- a/sandbox/src/main/kotlin/tech/libeufin/sandbox/ConversionService.kt
+++ b/sandbox/src/main/kotlin/tech/libeufin/sandbox/ConversionService.kt
@@ -6,7 +6,6 @@ import io.ktor.client.plugins.*
 import io.ktor.client.request.*
 import io.ktor.client.statement.*
 import io.ktor.http.*
-import kotlinx.coroutines.coroutineScope
 import kotlinx.coroutines.delay
 import kotlinx.coroutines.runBlocking
 import org.jetbrains.exposed.sql.and
@@ -103,22 +102,23 @@ private fun getUnsubmittedTransactions(bankAccountLabel: 
String): List<BankAccou
 
 /**
  * This function listens for regio-incoming events (LIBEUFIN_REGIO_TX)
  * and submits the related cash-out payment to Nexus.  The fiat payment will
  * then take place ENTIRELY on Nexus' responsibility.
  */
 suspend fun cashoutMonitor(
     httpClient: HttpClient,
-    bankAccountLabel: String = "admin",
+    watchedBankAccount: String = "admin",
     demobankName: String = "default" // used to get config values.
 ) {
     // Register for a REGIO_TX event.
     val eventChannel = buildChannelName(
         NotificationsChannelDomains.LIBEUFIN_REGIO_TX,
-        bankAccountLabel
+        watchedBankAccount
     )
     val objectMapper = jacksonObjectMapper()
     val demobank = getDemobank(demobankName)
-    val bankAccount = getBankAccountFromLabel(bankAccountLabel)
+    val bankAccount = getBankAccountFromLabel(watchedBankAccount)
     val config = demobank?.config ?: throw internalServerError(
         "Demobank '$demobankName' has no configuration."
     )
@@ -146,7 +146,7 @@ suspend fun cashoutMonitor(
         listenHandle.postgresListen()
         // but optimistically check for data, case some
         // arrived _before_ the LISTEN.
-        var newTxs = getUnsubmittedTransactions(bankAccountLabel)
+        var newTxs = getUnsubmittedTransactions(watchedBankAccount)
         // Data found, UNLISTEN.
         if (newTxs.isNotEmpty())
             listenHandle.postgresUnlisten()
@@ -158,7 +158,7 @@ suspend fun cashoutMonitor(
             // HTTP server.
             val isNotificationArrived = 
listenHandle.postgresGetNotifications(waitTimeout)
             if (isNotificationArrived && listenHandle.receivedPayload == 
"CRDT")
-                newTxs = getUnsubmittedTransactions(bankAccountLabel)
+                newTxs = getUnsubmittedTransactions(watchedBankAccount)
         }
         if (newTxs.isEmpty())
             continue
@@ -103,22 +102,23 @@ private fun getUnsubmittedTransactions(bankAccountLabel: 
 /**
  * This function listens for regio-incoming events (LIBEUFIN_REGIO_TX)
- * and submits the related cash-out payment to Nexus.  The fiat payment will
- * then take place ENTIRELY on Nexus' responsibility.
+ * on the 'watchedBankAccount' and submits the related cash-out payment
+ * to Nexus.  The fiat payment will then take place ENTIRELY on Nexus'
+ * responsibility.
  */
 suspend fun cashoutMonitor(

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]